@@ -3,7 +3,7 @@
 
 class TestConfig:
     _mysql_cfg = dict(
-        host='',
+        host='127.0.0.1',
         port=3306,
         username='chong',
         password=''
@@ -23,4 +23,9 @@ CREATE TABLE `t_user` (
   `create_ts` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   PRIMARY KEY (`id`)
 ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4;
-"""
\ No newline at end of file
+"""
+
+"""
+datetime类型列0000-00-00 00:00:00值不正确的解决语句：
+set @@global.sql_mode=(select replace(@@global.sql_mode,'NO_ZERO_IN_DATE,NO_ZERO_DATE',''));
+"""
